@@ -545,11 +545,13 @@ gs_updates_page_get_upgrades_cb (GObject *source_object,
 	} else if (gs_app_list_length (list) == 0) {
 		g_debug ("updates-shell: no upgrades to show");
 		gs_updates_page_clear_flag (self, GS_UPDATES_PAGE_FLAG_HAS_UPGRADES);
+		gtk_widget_set_visible (self->upgrade_banner, FALSE);
 	} else {
 		GsApp *app = gs_app_list_index (list, 0);
 		g_debug ("got upgrade %s", gs_app_get_id (app));
 		gs_upgrade_banner_set_app (GS_UPGRADE_BANNER (self->upgrade_banner), app);
 		gs_updates_page_set_flag (self, GS_UPDATES_PAGE_FLAG_HAS_UPGRADES);
+		gtk_widget_set_visible (self->upgrade_banner, TRUE);
 	}
 
 	/* only when both set */
@@ -957,25 +959,39 @@ gs_updates_page_perform_update_cb (GsPluginLoader *plugin_loader,
 }
 
 static void
-gs_updates_page_button_update_all_cb (GtkButton     *button,
-                                      GsUpdatesPage *self)
+update_all (GsUpdatesPage *self, GsAppList *apps)
 {
 	g_autoptr(GError) error = NULL;
-	g_autoptr(GsAppList) apps = NULL;
 	g_autoptr(GCancellable) cancellable = g_cancellable_new ();
 
-	/* do the offline update */
 	g_set_object (&self->cancellable, cancellable);
-	apps = gs_update_list_get_apps (GS_UPDATE_LIST (self->list_box_updates));
 	gs_plugin_loader_update_async (self->plugin_loader,
 				       apps,
 				       GS_PLUGIN_FAILURE_FLAGS_USE_EVENTS,
 				       self->cancellable,
 				       (GAsyncReadyCallback) gs_updates_page_perform_update_cb,
 				       self);
+}
+
+static void
+gs_updates_page_header_update_all_cb (GtkButton     *button,
+                                      GsUpdatesPage *self)
+{
+	g_autoptr(GsAppList) apps = NULL;
+
+	apps = gs_update_list_get_apps (GS_UPDATE_LIST (self->list_box_updates));
+	update_all (self, apps);
 	gtk_widget_set_sensitive (GTK_WIDGET (self->button_update_all), FALSE);
 }
 
+static void
+gs_updates_page_update_all_cb (GsUpdateList *update_list,
+                               GsAppList *apps,
+                               GsUpdatesPage *self)
+{
+	update_all (self, apps);
+}
+
 typedef struct {
 	GsApp		*app;
 	GsUpdatesPage	*self;
@@ -1338,6 +1354,8 @@ gs_updates_page_setup (GsPage *page,
 			  G_CALLBACK (gs_updates_page_activated_cb), self);
 	g_signal_connect (self->list_box_updates, "button-clicked",
 			  G_CALLBACK (gs_updates_page_button_clicked_cb), self);
+	g_signal_connect (self->list_box_updates, "update-all",
+			  G_CALLBACK (gs_updates_page_update_all_cb), self);
 
 	/* setup system upgrades */
 	g_signal_connect (self->upgrade_banner, "download-clicked",
@@ -1358,7 +1376,7 @@ gs_updates_page_setup (GsPage *page,
 	gtk_widget_set_visible (self->button_update_all, TRUE);
 	gtk_style_context_add_class (gtk_widget_get_style_context (self->button_update_all), "suggested-action");
 	gtk_container_add (GTK_CONTAINER (self->header_end_box), self->button_update_all);
-	g_signal_connect (self->button_update_all, "clicked", G_CALLBACK (gs_updates_page_button_update_all_cb), self);
+	g_signal_connect (self->button_update_all, "clicked", G_CALLBACK (gs_updates_page_header_update_all_cb), self);
 
 	self->header_start_box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
 	gtk_widget_set_visible (self->header_start_box, TRUE);
@@ -1399,6 +1417,10 @@ gs_updates_page_dispose (GObject *object)
 		g_cancellable_cancel (self->cancellable_refresh);
 		g_clear_object (&self->cancellable_refresh);
 	}
+	if (self->cancellable_upgrade_download != NULL) {
+		g_cancellable_cancel (self->cancellable_upgrade_download);
+		g_clear_object (&self->cancellable_upgrade_download);
+	}
 
 	g_clear_object (&self->builder);
 	g_clear_object (&self->plugin_loader);
